Method: String#squish
- Defined in:
- lib/droiuby/support/string/filters.rb
#squish ⇒ Object
Returns the string, first removing all whitespace on both ends of the string, and then changing remaining consecutive whitespace groups into one space each.
Note that it handles both ASCII and Unicode whitespace like mongolian vowel separator (U+180E).
%{ Multi-line
string }.squish # => "Multi-line string"
" foo bar \n \t boo".squish # => "foo bar boo"
11 12 13 |
# File 'lib/droiuby/support/string/filters.rb', line 11 def squish dup.squish! end |